# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class ChatMessageType(str, Enum):
    """
    An enumeration.
    """

    """
    allowed enum values
    """
    TEXT = 'TEXT'
    AUDIO = 'AUDIO'
    TOOL_CALL = 'TOOL_CALL'
    TOOL_RESULTS = 'TOOL_RESULTS'
    NODE_START = 'NODE_START'
    NODE_END = 'NODE_END'
    AGENT_START = 'AGENT_START'
    AGENT_END = 'AGENT_END'
    ERROR = 'ERROR'
    SESSION_START = 'SESSION_START'
    SESSION_END = 'SESSION_END'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ChatMessageType from a JSON string"""
        return cls(json.loads(json_str))


